#!/bin/bash
COM_ERR=1
INSTALL_DIR=/opt/ups
SCRIPTS=scripts
CONF_FILE=ups.conf
LIB=ups.lib
DAEMON=ups_turn_off.sh
source $INSTALL_DIR/$CONF_FILE
ARGS="-i2c_addr $I2C_ADDR"


if [ $# -eq 0 ]
then
	echo "Please type \"lcd.sh -help\" for a list of commands"
	exit 0
fi


if [ $1 = "-help" ]
then
	COM_ERR=0
	
	echo "List of commands"
	echo ""
	
	echo "-help"
	echo "-board_info"
	echo "-status"
	echo "-charger_<on/off>"
	echo "-battery_type <LITHIUM/NIMH/ALKALINE>"
	echo "-battery_full <auto/volts>"
	echo "-battery_low <auto/volts>"
	echo "-power_cycle <sec>"
	echo "-power_off <sec>"
	echo "-usb_v"
	echo "-battery_v"
	echo "-temp"
	echo "-led_<on/off>"
	echo "-buzzer_<on/off>"
	echo "-usb_auto_on_<enable/disable>"
	echo "-usb_wake_up_<on/off>"
	echo "-timed_wake_up_<on/off> <sleep_minutes>"
	echo "-battery_wake_up_<on/off> <voltage>"
	echo "-i2c_find"
	echo "-i2c_change_addr <new_addr>"
	echo "-sw_rev"
	echo "-read_conf"
	echo "-fw_update <file_name>"
	echo "-read_log"
	echo "-clear_errors"

	
#Read Board information
elif [ $1 = "-board_info" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -board_info
	exit $?

#Read Overall StatusBoard information
elif [ $1 = "-status" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -status
	exit $?
		
#Read USB Voltage
elif [ $1 = "-usb_v" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -usb_v
	exit $?
	
#Read Battery Voltage
elif [ $1 = "-battery_v" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -battery_v
	exit $?
	
#Disable LED
elif [ $1 = "-led_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -led_off
	exit $?	
	
#Enable LED
elif [ $1 = "-led_on" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -led_on
	exit $?	

#On initial power up, wait for push button before turning power on
elif [ $1 = "-usb_auto_on_disable" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -usb_auto_on_disable
	exit $?	
	
#On initial power up, if USB is present then don't wait for push button
#and just turn power on
elif [ $1 = "-usb_auto_on_enable" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -usb_auto_on_enable
	exit $?	

#Enable usb as a wake up source from sleep, as soon as USB power is stable
#the UPS will wake up from sleep
elif [ $1 = "-usb_wake_up_on" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -usb_wake_up_on
	exit $?
	
#Disable usb as a wake up source from sleep
elif [ $1 = "-usb_wake_up_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -usb_wake_up_off
	exit $?
	

#Disable Buzzer
elif [ $1 = "-buzzer_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -buzzer_off
	exit $?	
	

#Enable Buzzer
elif [ $1 = "-buzzer_on" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -buzzer_on
	exit $?	


#Disable battery charger
elif [ $1 = "-charger_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -charger_off
	exit $?	
	
#Enable battery charger
elif [ $1 = "-charger_on" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -charger_on
	exit $?	
	
#Set the battery type to one of <LITHIUM/NIMH/ALKALINE>
elif [ $1 = "-battery_type" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -battery_type $2
		exit $?
	else
		echo "ERROR: Expecting another argument for the type of battery <LITHIUM/NIMH/ALKALINE>"
	fi

#Set the battery full voltage.
elif [ $1 = "-battery_full" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -full_battery_v $2
		exit $?
	else
		echo "ERROR: Expecting another argument, auto or a voltage"
		echo "For example : ups.sh -battery_full auto"
		echo "Or ups.sh -battery_full 3.75"
	fi

#Set the battery low voltage.
elif [ $1 = "-battery_low" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -low_battery_v $2
		exit $?
	else
		echo "ERROR: Expecting another argument, auto or a voltage"
		echo "For example : ups.sh -low_battery_v auto"
		echo "Or ups.sh -low_battery_v 3.25"
	fi

#Read Board Temperature
elif [ $1 = "-temp" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -temp
	exit $?
		
#Tells the ups to wait (0-255) seconds, then power cycle 5V
elif [ $1 = "-power_cycle" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -power_cycle $2
		exit $?
	else
		echo "ERROR: Expecting an argument for seconds delay"
	fi

#Tells the ups to wait (0-255) seconds, then turn power off
#Push button needs to be pressed to turn power on again
elif [ $1 = "-power_off" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -power_off $2
		exit $?
	else
		echo "ERROR: Expecting an argument for seconds delay"
	fi

#Sets up timed wake up for (1-65535) minutes
elif [ $1 = "-timed_wake_up_on" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -timed_wake_up_on $2
		exit $?
	else
		echo "ERROR: Expecting an argument for minutes sleep"
		echo "For example ups.sh -timed_wake_up_on 60"
	fi

#Disables timed wake up
elif [ $1 = "-timed_wake_up_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -timed_wake_up_off
	exit $?
	
#Sets up automatic wake up when battery gets charged to X volts
elif [ $1 = "-battery_wake_up_on" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -battery_wake_up_on $2
		exit $?
	else
		echo "ERROR: Expecting an argument for volts"
		echo "For example ups.sh -battery_wake_up_on 3.5"
	fi

#Disables battery voltage based wake up
elif [ $1 = "-battery_wake_up_off" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -battery_wake_up_off
	exit $?
		

		
#Scans the i2c bus to find the device
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_find" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -i2c_find
	
	tmp="$(printf '%x\n' $?)"
	
	if [ $tmp != ff ]
	then
		#Update .conf file
		echo "Updating I2C_ADDR variable inside $INSTALL_DIR/$CONF_FILE to $tmp"
		sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$tmp" $INSTALL_DIR/$CONF_FILE
	else
		echo $?
	fi


#Change I2C address
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_change_addr" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB $ARGS -i2c_change_addr $2
		
		if [ $? -eq 0 ]
		then
			#Update .conf file
			echo "Updating I2C_ADDR variable inside $CONF_FILE to $2"
			sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$2" $INSTALL_DIR/$CONF_FILE
		else
			echo "ERROR: Failed to update I2C address."
		fi
		
		exit $?
	else
		echo "ERROR: Expecting a hex number as an argument"
	fi
		
#Print software revision
elif [ $1 = "-sw_rev" ]
then
	sudo $INSTALL_DIR/$LIB $ARGS -sw_rev
	exit $?
	
#Read the .conf file
elif [ $1 = "-read_conf" ]
then
	echo "Reading $INSTALL_DIR/$CONF_FILE"
	echo ""
	cat $INSTALL_DIR/$CONF_FILE
	exit $?


#Firmware update
elif [ $1 = "-fw_update" ]
then
	
	if [ $# -ne 2 ]
	then
		echo "Missing file name argument"
	elif [ -f $2 ]
	then
		COM_ERR=0
		
		sudo pkill $DAEMON
		sudo $INSTALL_DIR/$LIB $ARGS -fw_update $2
		
		if [ $? -eq 0 ]
		then
			sudo $INSTALL_DIR/$SCRIPTS/$DAEMON &
		fi
	else
		echo "File doesn't exist"	
	fi
	
	exit $?

#Read Log
elif [ $1 = "-read_log" ]
then
	COM_ERR=0
	sudo grep UPS /var/log/messages
	exit $?

#Clear errors
elif [ $1 = "-clear_errors" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB $ARGS -clear_errors
	exit $?
	
else
	echo "Unknown command($1), please use -help to see valid commands"
fi



if [ $COM_ERR = "1" ]
then
	echo "Error"
fi
	
	